@@ -6,7 +6,7 @@ use warnings;
 
 # External packages used by packages in this file, that don't export symbols:
 use only 'Locale::KeyedText' => '1.72.0-';
-use only 'Rosetta' => '0.723.0';
+use only 'Rosetta' => '0.722.0-';
 
 ###########################################################################
 ###########################################################################
@@ -19,7 +19,7 @@ Readonly my $EMPTY_STR => q{};
 ###########################################################################
 
 { package Rosetta::Shell; # module
-    use version; our $VERSION = qv('0.1.1');
+    use version; our $VERSION = qv('0.1.2');
 
     # External packages used by the Rosetta::Shell module, that do export symbols:
     # (None Yet)
@@ -140,7 +140,7 @@ Interactive command shell for the Rosetta DBMS
 
 =head1 VERSION
 
-This document describes Rosetta::Shell version 0.1.1.
+This document describes Rosetta::Shell version 0.1.2.
 
 =head1 SYNOPSIS
 
@@ -173,7 +173,7 @@ It also requires these Perl 5 classes that are on CPAN:
 L<Locale::KeyedText-(1.72.0...)|Locale::KeyedText> (for error messages).
 
 It also requires these Perl 5 classes that are in the current distribution:
-L<Rosetta-0.723.0|Rosetta>.
+L<Rosetta-(0.722.0...)|Rosetta>.
 
 =head1 INCOMPATIBILITIES
 
